InTrackConfig class

Constructors

InTrackConfig(String _appKey)

Properties

androidAuthKey → String?
no setter
appKey → String
Getters of private members
no setter
collectAdvertisingId → bool?
no setter
deviceID → String?
no setter
enableUnhandledCrashReporting → bool?
no setter
hashCode → int
The hash code for this object.
no setterinherited
inAppAutoTracking → bool?
no setter
inAppMessaging → bool?
no setter
inAppUseShortName → bool?
no setter
iosAuthKey → String?
no setter
location → Map<String, String>?
no setter
locationCity → String?
no setter
locationCountryCode → String?
no setter
locationGpsCoordinates → String?
no setter
locationIpAddress → String?
no setter
loggingEnabled → bool?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkLocalStorageMaxFileSize → double
no setter

Methods

enableCrashReporting() → InTrackConfig
Call to enable uncaught crash reporting
enableInAppMessaging() → InTrackConfig
enabling inApp messaging
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seCollectAdvertisingId(bool value) → InTrackConfig
setAndroidAuthKey(String authKey) → InTrackConfig
auth key for the application being tracked; find in the InTrack Dashboard under Management > Applications.
setAppKey(String appKey) → InTrackConfig
app key for the application being tracked; find in the InTrack Dashboard under SDK.
setDeviceId(String deviceID) → InTrackConfig
unique ID for the device the app is running on.
setIOSAuthKey(String authKey) → InTrackConfig
setLoggingEnabled(bool enabled) → InTrackConfig
Set to true of you want to enable intrack internal debugging logs those logs will be printed to the console
setSDKLocalStorageMaxFileSize(double maxFileSizeInKiloBytes) → InTrackConfig
limits local storage file size to a max value in KB(KiloBytes) this will not impact basic functionality of the sdk ,however, setting it will impact amount of cached requests to a certain level and older ones will get evicted!
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited